void checkPowerButton() {

  int reading = digitalRead(powerSwitch);     // check if the power switch is on                                               
  if (reading != lastPowerButtonState) {   // if the power switch has moved...
   
    lastDebounceTime = millis();      //  log the time          
  }
  if ((millis() - lastDebounceTime) > debounceDelay ) {  // if we've waited more than debounce time...                                   
    if (reading != powerButtonState) {                        // and the switch has moved...
      powerButtonState = reading;                             // log the switch state

      if (powerButtonState == LOW) {                                  // check if run status is off (0)
        preheatOn = 1;
         Serial.println ("Power Switch On ");
      } else {
        if (powerButtonState == HIGH) {                                // check if run status is on
          powerOff();
           Serial.println ("Power Switch Off ");
        }
      }
    }
  }
  lastPowerButtonState = reading;
}

void preheat() {
  if (preheatOn == 1) {                                     // if we are in preheat mode
    currentMillis = millis();                               // set the clock
    preheatStartTime = currentMillis;                       // log the time
    digitalWrite (preheatRelay, HIGH);                      // turn on the preheat relay
    rectifierOn = 1;                                        // get ready to start the rectifier
    preheatOn = 0;                                          // we are no longer preparing for preheat
    Serial.println ("Preheat ");                            
  }
}

void startRectifier() {
  if (rectifierOn == 1) {                                       // if we are preparing to start the rectifier
    currentMillis = millis();                                   // set the clock
    rectifierStartTime = currentMillis;                         // log the time
    if ((currentMillis - preheatStartTime) > preheatDelay) {    // if we've preheated long enogh...
      digitalWrite (rectifierRelay, HIGH);                      // turn on the rectifier relay
      inrushOn = 1;                                             // get ready for inrush
      rectifierOn = 0;                                          // we are no longer preparing to turn on the rectifier
      Serial.println ("Rectifier On ");
    }
  }
}


void inrush() {
  if (inrushOn == 1) {                                            // if we are preparing for inrush...
    currentMillis = millis();                                     // set the clock
    inrushStartTime = millis();                                   // log the time
    if ((currentMillis - rectifierStartTime) > rectifierDelay) {  // if the rectifier has been running long enough...
      digitalWrite (inrushRelay, HIGH);                           // turn on the inrush relay
      powerOn = 1;                                                //get ready to turn on the power relay
      inrushOn = 0;                                               // we are no longer preparing for inrush
      Serial.println ("Inrush On ");
    }
  }
}

void power() {
  if (powerOn == 1) {                                             // if we are preparing to turn on power relay...
    currentMillis = millis();                                     // set the clock
    powerStartTime = currentMillis;                               // log the time
    if ((currentMillis - inrushStartTime) > inrushDelay) {        // if the inrush relay has been on long enough...
      digitalWrite(powerRelay, HIGH);                             // turn on the power relay
      overlapOn = 1;                                              // get ready to turn off the inrush relay
      powerOn = 0;                                                // we are no longer waiting to turn on the power relay
      Serial.println ("Power On ");
    }
  }
}

void overlap() {
  if (overlapOn == 1) {                                           // if we are preparing to turn off the inrush relay
    currentMillis = millis();                                     // set the clock
    if ((currentMillis - powerStartTime) >  overlapDelay) {       // if the power erelay has been on long enough
      digitalWrite (inrushRelay, LOW);                            // turn off the inrush relay
      overlapOn = 0;                                              // we are no longer waiting to turn off the inrush relay
      Serial.println("Inrush Off ");
      
    }
  }
}

void powerOff() {
  digitalWrite (preheatRelay, LOW);                              // turn off the preheat relay
  digitalWrite (rectifierRelay, LOW);                            // turn off the rectifier relay
  digitalWrite (inrushRelay, LOW);                               // turn off the inrush relay
  digitalWrite (powerRelay, LOW);                                // turn off the power relay
  Serial.println("All Off");
}

